
# Example 6.4:  Exponential Smoothing
# Example 6.5:  Thresholding
 rm(list=ls())

######## Reading Data   ##############

 RiskFactors = read.csv("../Figse/PCA/RiskFactors.csv")
 RiskFactors[,2] = RiskFactors[,2]*100        #convert to percentage
 RiskFactors[,5:7] = RiskFactors[,5:7]/100    #convert to percentage
 RiskFactors[,8] = RiskFactors[,8]*100        #basis point  

 Dates = as.vector(RiskFactors[,1])
 Dates = strptime(Dates, "%m/%d/%Y") #convert to  POSIXlt (a date class)
 Names = c("Date", "Market risk", "Volatility risk", "Exchange rate risk",
 		"Maturity risk", "Default risk", "Liquidity risk", 
		"Size effect", "Short term rate")

 #################### Exponential Smoothing ####################
 n = nrow(RiskFactors)
 lambda = 0.94
 Sigma = array(0,c(2,2,n+1))       
 change = c(0,diff(RiskFactors[,3]))        #changes of volaitlity
 for(i in 1:n)
  {tmp = as.numeric(c(RiskFactors[i,2],change[i]))
   Sigma[,,i+1]=lambda*Sigma[,,i] + (1-lambda)*tmp%*%t(tmp)
  }
 Sigma = Sigma[,,-1]           #remove the initial values
 
 leverage = Sigma[1,2,]/sqrt(Sigma[1,1,])/sqrt(Sigma[2,2,])
 
 postscript("Fig63.eps", width=4.4, height=4.8, horizontal=F, pointsize=8)
 par(mfrow = c(2,2), mar=c(4,2,2,1)+0.1, cex=0.8)
 
 plot(Dates, sqrt(Sigma[1,1,]), type="l", col=4)
 title("Daily volality of SP500 Returns")
 
 plot(Dates, sqrt(Sigma[2,2,]), type="l", col=4)
 title("SD of changes of VIX")
 
 plot(Dates, leverage, type="l", col=4, ylim=c(-1,0))
 title("Correlation of SPX returns and VIX")
 
 plot(Dates, Sigma[2,1,], type="l", col=4)
 title("Covariance of SPX returns and VIX")
 
 ################ Example 6.5:  Thresholding of Correlation matrix ###########
 
    tmp = cor(RiskFactors[801:n,2:9])
    round(tmp,2)                                  #2-23-04 to 2-28-2011
    eigen(tmp)
    
    tmp1 = tmp*I(abs(tmp) > 0.15)
    eigen(tmp1)
    round(tmp1,2)
